<template>
  <ChooseInput :modelValue="modelValue" @click="handleOpen()"></ChooseInput>
</template>

<script setup lang="ts">
import ChooseInput from './ChooseInput.vue';
import { Popup, DatePicker } from '@nutui/nutui-taro';
import { Portal } from 'senin-mini/components';
import { h } from 'vue';
import dayjs from 'dayjs';

defineOptions({
  name: 'ChooseInputWithDatePicker',
});

type Props = {
  modelValue: string | number;
};

const props = withDefaults(defineProps<Props>(), {});

const emit = defineEmits<{
  (e: 'update:modelValue', val: string | number): void;
}>();

function handleOpen() {
  const _modelValue = [props.modelValue];
  Portal.add((key) => {
    return h(
      Portal.Container,
      { keyNumber: key, delayOpen: true },
      {
        default: ({ open, onClose }) =>
          h(
            Popup,
            {
              visible: open.value,
              'onUpdate:visible': (value) => !value && onClose(),
              position: 'bottom',
            },
            {
              default: () =>
                h(DatePicker, {
                  modelValue: _modelValue,
                  onCancel: onClose,
                  onConfirm: ({ selectedValue }) => {
                    console.log('selectedValue: ', selectedValue);
                    emit('update:modelValue', dayjs(selectedValue).format('YYYY-MM-DD'));
                    onClose();
                  },
                }),
            }
          ),
      }
    );
  });
}
</script>
